@@ -23,6 +23,8 @@ class Levenberg_Marquart():
         self.verbose = True
         self.f0 = self.forward_model(self.initial_prediction)
 
+        self.parameter_update = 'nielson'
+
 
 
     def direction(self):
@@ -31,6 +33,9 @@ class Levenberg_Marquart():
         if self.verbose:
             print('Finding the damping parameter')
         L = 1
+
+        mult = 2
+
         while 1:
 
 
@@ -97,9 +102,21 @@ class Levenberg_Marquart():
                 return dir_zeros
             else:
                 if rho<0.8 or rho > 1.2:
-                    self.gamma = self.gamma*mth.pi
+
+                    if self.parameter_update == 'levenberg':
+                        self.gamma = self.gamma*3
+                    elif self.parameter_update == 'nielson':
+                        mult = 2*mult
+                        self.gamma = self.gamma*mult
+
+
                 elif (rho >0.99999 and rho < 1) or (rho > 1 and rho <1.00001):
-                    self.gamma = self.gamma/2
+
+                    if self.parameter_update == 'levenberg':
+                        self.gamma = self.gamma/2
+                    elif self.parameter_update == 'nielson':
+                        mult = 2
+                        self.gamma = self.gamma*np.max([1/3, 1-(2*rho-1)**3])
                 else:
                     self.f0 = f
                     return dir
